@@ -39,7 +39,7 @@ MozRepl::RemoteObject - treat Javascript objects as Perl objects
 =cut
 
 use vars qw[$VERSION $objBridge @CARP_NOT];
-$VERSION = '0.13';
+$VERSION = '0.14';
 
 @CARP_NOT = (qw[MozRepl::RemoteObject::Instance
                 MozRepl::RemoteObject::TiedHash
@@ -333,7 +333,6 @@ sub install_bridge {
     my $rn = $options{repl}->repl;
     #warn "<$rn>";
     $options{ json } ||= JSON->new->allow_nonref->ascii; # We send ASCII
-    #$options{ json } ||= JSON->new->allow_nonref->latin1;
 
     # Load the JS side of the JS <-> Perl bridge
     my $c = $objBridge; # make a copy
@@ -1114,7 +1113,7 @@ sub __event {
     if ($type eq 'click') {
         $fn = $self->bridge->declare(<<'JS');
         function(target,name) {
-            var event = content.document.createEvent('MouseEvents');
+            var event = target.ownerDocument.createEvent('MouseEvents');
             event.initMouseEvent(name, true, true, window,
                                  0, 0, 0, 0, 0, false, false, false,
                                  false, 0, null);
@@ -1124,7 +1123,7 @@ JS
     } else {
         $fn = $self->bridge->declare(<<'JS');
         function(target,name) {
-        var event = content.document.createEvent('Events');
+        var event = target.ownerDocument.createEvent('Events');
         event.initEvent(name, true, true);
         target.dispatchEvent(event);
     }
